import { ApiRespons, FeilType, fetcher, ikkeRevalidate } from "../../api/api";
import { ANALYSE_API_URL } from "../../utils/baseUrl";
import useSWR from "swr";
import { Dayjs } from "dayjs";
import { tilEnkelTimestampStr } from "../../utils/tid";
import { Geometry } from "geojson";
import { TransportKorridor } from "../forsinkelseSide/useHentTransportKorridorerGeometri";

export function useHentRiksvegruterDetaljer(
    fraDato: Dayjs,
    tilDato: Dayjs,
    riksvegrute: TransportKorridor,
): ApiRespons<RiksvegruterDetaljerDto[]> | undefined {
    const customFetcher = async (): Promise<ApiRespons<RiksvegruterDetaljerDto[]>> =>
        await fetcher<RiksvegruterDetaljerDto[]>(
            `${ANALYSE_API_URL}/riksvegruterDetaljer?fraDato=${tilEnkelTimestampStr(fraDato)}&tilDato=${tilEnkelTimestampStr(tilDato)}&riksvegruteId=${riksvegrute.id}`,
            FeilType.KUNNE_IKKE_HENTE_FORSINKELSESDATA,
        );
    const { data } = useSWR<ApiRespons<RiksvegruterDetaljerDto[]>>(
        `${fraDato}-${tilDato}`,
        customFetcher,
        ikkeRevalidate,
    );
    return data;
}

export interface RiksvegruterDetaljerDto {
    id: string;
    startDato: string;
    sluttDato: string;
    timerArbeid: number;
    beskrivelse: string;
    totalForsinkelseTimer: number;
    totalKostnadKroner: number;
    forsinkelsePerDato: { [date: string]: number };
    kostnadPerDato: { [date: string]: number };
    geografi: Geometry;
}
