import React, { useCallback, useState } from "react";
import { useCloseOnOutsideClick } from "../../../hooks/useCloseOnOutsideClick";
import { Trekkspill } from "../../../components/fellesKomponenter/trekkspill/Trekkspill";
import { Checkbox } from "../../../components/fellesKomponenter/checkboxer/Checkbox";
import styled from "styled-components";
import { Søkefelt } from "../../../components/fellesKomponenter/søkefelt/Søkefelt";
import { useAtom } from "jotai/index";
import { filtrerteHendelserAtom } from "../../api/apiAtoms";

interface FilterTrekkspillProps {
    alleElementerIUtvalg: string[];
    valgteElementer: string[];
    setValgteElementer: (fylke?: string, kommune?: string) => void;
    filternavn: "fylker" | "kommuner";
}
export const FilterTrekkspill = ({
    alleElementerIUtvalg,
    valgteElementer,
    setValgteElementer,
    filternavn,
}: FilterTrekkspillProps) => {
    const [trekkspillÅpen, settTrekkspillÅpen] = useState(false);
    const [søkeord, setSøkeord] = useState("");
    const filtrerteElementer =
        alleElementerIUtvalg
            .filter((e) => e.toLowerCase().includes(søkeord.toLowerCase()))
            .sort((a, b) => a.localeCompare(b)) ?? [];

    const lukkDropDown = useCallback(() => {
        settTrekkspillÅpen(false);
    }, [settTrekkspillÅpen, valgteElementer]);

    const handleToggle = (tittel: string) => {
        if (filternavn === "fylker") {
            setValgteElementer(tittel, undefined);
        } else {
            setValgteElementer(undefined, tittel);
        }
    };

    useCloseOnOutsideClick(filternavn, lukkDropDown);

    return (
        <div id={filternavn}>
            <Trekkspill
                åpen={trekkspillÅpen}
                tittel={`Velg ${filternavn}`}
                type={"Ramme"}
                onClick={() => {
                    settTrekkspillÅpen(!trekkspillÅpen);
                }}
                width="250px"
            >
                <Innhold>
                    <Søkefelt søkeord={søkeord} setSøkeord={setSøkeord} />
                    {filtrerteElementer.map((element, i) => (
                        <Checkbox
                            key={`${element}-${i}`}
                            onChange={(e) => {
                                handleToggle(element);
                            }}
                            checked={valgteElementer.includes(element)}
                            value={element}
                            størrelse={"S"}
                            tekstStørrelse={"M"}
                        >
                            {element}
                        </Checkbox>
                    ))}
                </Innhold>
            </Trekkspill>
        </div>
    );
};

const Innhold = styled.div`
    padding: 20px 16px;
    background: var(--white);
    display: flex;
    flex-direction: column;
    gap: 8px;
`;
