import { Hendelser } from "../../forsinkelseSide/useHentForsinkelsesdata";
import { Tekst } from "../../../components/fellesKomponenter/typografi/Tekst";
import { Trekkspill } from "../../../components/fellesKomponenter/trekkspill/Trekkspill";
import fylkeliste from "../../../driftsportalSide/tekst/fylker.json";
import { Checkbox } from "../../../components/fellesKomponenter/checkboxer/Checkbox";
import React, { useCallback, useEffect, useMemo, useState } from "react";
import styled from "styled-components";
import { useCloseOnOutsideClick } from "../../../hooks/useCloseOnOutsideClick";
import { FilterTrekkspill } from "./FilterTrekkspill";
import { useAtom } from "jotai/index";
import { detaljerteHendelserAtom, filtrerteHendelserAtom } from "../../api/apiAtoms";
import { useAtomValue, useSetAtom } from "jotai";

export const Filtermeny = () => {
    const setFiltrerteHendelser = useSetAtom(filtrerteHendelserAtom);
    const detaljerteHendelser = useAtomValue(detaljerteHendelserAtom);

    const lokasjon = detaljerteHendelser.map((hendelse) => hendelse.lokasjon).flat();
    const fylker = lokasjon.map((sted) => sted.fylke);
    const unikeFylker = Array.from(new Set(fylker));

    const kommuner = lokasjon.map((sted) => sted.kommuner).flat();
    const unikeKommuner = Array.from(new Set(kommuner));

    const [valgteFylker, settValgteFylker] = useState<string[]>(unikeFylker);
    const [valgteKommuner, settValgteKommuner] = useState<string[]>(unikeKommuner);

    const håndterValgteFylkerOgKommuner = (fylke?: string, kommune?: string) => {
        if (fylke && valgteFylker.includes(fylke)) {
            const kommunerIFylket = lokasjon
                .filter((sted) => sted.fylke === fylke)
                .map((sted) => sted.kommuner)
                .flat();
            settValgteFylker(valgteFylker.filter((valgtFylke) => valgtFylke !== fylke));
            settValgteKommuner(
                valgteKommuner.filter((valgtKommune) => !kommunerIFylket.includes(valgtKommune)),
            );
        } else if (fylke) {
            settValgteFylker([...valgteFylker, fylke]);
        }

        if (kommune && valgteKommuner.includes(kommune)) {
            settValgteKommuner(valgteKommuner.filter((valgtKommune) => valgtKommune !== kommune));
        } else if (kommune) {
            settValgteKommuner([...valgteKommuner, kommune]);
        }
    };

    useEffect(() => {
        const nyeFiltrerteHendelser: Hendelser[] = detaljerteHendelser.filter(
            (hendelse: Hendelser) =>
                hendelse.lokasjon.some((lokasjon) => valgteFylker.includes(lokasjon.fylke)) ||
                hendelse.lokasjon.some((lokasjon) =>
                    lokasjon.kommuner.some((kommune) => valgteKommuner.includes(kommune)),
                ),
        );

        setFiltrerteHendelser(nyeFiltrerteHendelser);
    }, [detaljerteHendelser, valgteFylker, valgteKommuner]);

    return (
        <Container>
            <Tekst bold={true} størrelse={"M"}>
                Filtrer hendelser
            </Tekst>
            <TrekkspillWrapper>
                <FilterTrekkspill
                    alleElementerIUtvalg={unikeFylker}
                    valgteElementer={valgteFylker}
                    setValgteElementer={håndterValgteFylkerOgKommuner}
                    filternavn={"fylker"}
                />
                <FilterTrekkspill
                    alleElementerIUtvalg={unikeKommuner}
                    valgteElementer={valgteKommuner}
                    setValgteElementer={håndterValgteFylkerOgKommuner}
                    filternavn={"kommuner"}
                />
            </TrekkspillWrapper>
        </Container>
    );
};

const Container = styled.div`
    display: flex;
    flex-direction: column;
`;

const TrekkspillWrapper = styled.div`
    display: flex;
    flex-wrap: wrap;
    gap: 1rem;
    flex-direction: row;
`;
