"use client";

import { AnalyseSideHeader } from "../components/analyseSideHeader";
import ErrorBoundary from "../../components/feil/ErrorBoundary";
import { AuthenticationWrapper } from "../../components/AuthenticationWrapper";
import styled from "styled-components";
import { Heading } from "../../components/fellesKomponenter/typografi/Heading";
import React, { useState } from "react";
import dayjs from "dayjs";
import { useHentForsinkelsesdata } from "../forsinkelseSide/useHentForsinkelsesdata";
import BarplotForsinkelse from "./BarplotForsinkelse";
import { Datofelt } from "../../components/fellesKomponenter/inputfelt/Datofelt";
import { KnappPrimær } from "../../components/fellesKomponenter/knapper/KnappPrimær";
import { PieChartUsikkerhet } from "./PieChartUsikkerhet";
import { Filtermeny } from "../components/fellesKomponenter/Filtermeny";
import { useAtom } from "jotai/index";
import {
    detaljerteHendelserAtom,
    detaljerteHendelserResponsAtom,
    filtrerteHendelserAtom,
} from "../api/apiAtoms";
import { useAtomValue } from "jotai";

export const ForsinkelseDetaljerSide = () => {
    const [lokalStartDato, setLokalStartDato] = useState(dayjs().add(-1, "month"));
    const [lokalSluttDato, setLokalSluttDato] = useState(dayjs());
    const [startDato, setStartDato] = useState(lokalStartDato);
    const [sluttDato, setSluttDato] = useState(lokalSluttDato);
    const filtrerteHendelser = useAtomValue(filtrerteHendelserAtom);
    const hendelserRespons = useAtomValue(detaljerteHendelserResponsAtom);

    useHentForsinkelsesdata(startDato, sluttDato);

    const handleSubmit = (e: React.FormEvent<HTMLFormElement>) => {
        e.preventDefault();
        setStartDato(lokalStartDato);
        setSluttDato(lokalSluttDato);
    };

    return (
        <ErrorBoundary info={`side: Analyseportal detaljert forsinkelse`}>
            <AuthenticationWrapper>
                <AnalyseSideHeader side={"forsinkelserDetaljert"} />
                <Sideinnhold>
                    <FilterContainer>
                        <StyledForm onSubmit={handleSubmit}>
                            <Datofelt
                                dato={lokalStartDato}
                                setDato={setLokalStartDato}
                                tittel={"Fra dato"}
                            />
                            <Datofelt
                                dato={lokalSluttDato}
                                setDato={setLokalSluttDato}
                                tittel={"Til dato"}
                            />
                            <KnappPrimær type="submit" size="Small">
                                Hent data
                            </KnappPrimær>
                        </StyledForm>
                        {hendelserRespons?.suksess && <Filtermeny />}
                    </FilterContainer>
                    <AnalyseContainer>
                        {hendelserRespons?.suksess ? (
                            <>
                                <Heading as={"h3"} styleLevel={"3"}>
                                    Barplot
                                </Heading>
                                <BarplotForsinkelse data={filtrerteHendelser} />
                                <Heading as={"h3"} styleLevel={"3"}>
                                    Usikkerhet kakediagram
                                </Heading>
                                <PieChartUsikkerhet hendelser={filtrerteHendelser} />
                            </>
                        ) : (
                            <>
                                {hendelserRespons?.feilmelding ? (
                                    <div>{hendelserRespons.feilmelding}</div>
                                ) : (
                                    <div>Laster...</div>
                                )}
                            </>
                        )}
                    </AnalyseContainer>
                </Sideinnhold>
            </AuthenticationWrapper>
        </ErrorBoundary>
    );
};

const Sideinnhold = styled.main`
    display: flex;
    flex-direction: column;
    gap: 2rem;
`;

const FilterContainer = styled.div`
    padding: 1rem;
    display: flex;
    flex-direction: column;
    gap: 1rem;
    background-color: var(--gray-light);
`;

const AnalyseContainer = styled.div`
    padding: 1rem;
    display: flex;
    flex-direction: column;
    gap: 1rem;
`;

const StyledForm = styled.form`
    display: flex;
    flex-direction: row;
    gap: 1rem;
    flex-wrap: wrap;
    align-items: end;
`;

export default ForsinkelseDetaljerSide;
