import { UsikkerhetPerKategori } from "../forsinkelseSide/useHentForsinkelsesdata";
import {
    PIECHART_COLORS,
    renderCustomizedLabelDetailedOuter,
    renderCustomizedLabelInner,
    usikkerhetsdataTilStatistikkdata,
} from "../utils/piechartUtils";
import { Cell, Pie, PieChart, Tooltip } from "recharts";
import React from "react";
import styled from "styled-components";
import { Tekst } from "../../components/fellesKomponenter/typografi/Tekst";
import { PieChartTooltip } from "./PieChartTooltip";

export const PieChartPerKategori = ({
    aggregertUsikkerhet,
}: {
    aggregertUsikkerhet: UsikkerhetPerKategori[];
}) => {
    const antallPerUsikkerhet = aggregertUsikkerhet.map(
        ({ usikkerhetKategori, usikkerhetAntall, totaltAntall }) => {
            return {
                usikkerhetKategori,
                usikkerhet: usikkerhetsdataTilStatistikkdata(usikkerhetAntall),
                totaltAntall: totaltAntall,
            };
        },
    );

    const customTooltip = <PieChartTooltip />;

    return (
        <Container>
            {antallPerUsikkerhet.map((usikkerhet, index) => (
                <ColumnWrapper key={usikkerhet.usikkerhetKategori + index.toString()}>
                    <StyledTekst størrelse={"M"} noMargin={true}>
                        {usikkerhet.usikkerhetKategori}
                    </StyledTekst>
                    <PieChart width={260} height={200}>
                        <Pie
                            data={usikkerhet.usikkerhet}
                            cx={"50%"}
                            cy={"50%"}
                            labelLine={false}
                            label={renderCustomizedLabelDetailedOuter}
                            outerRadius={60}
                            innerRadius={33}
                            fill="#8884d8"
                            dataKey="value"
                        >
                            {usikkerhet.usikkerhet.map((entry, index) => (
                                <Cell
                                    key={`celldetaljert-${index}`}
                                    fill={PIECHART_COLORS[index % PIECHART_COLORS.length]}
                                />
                            ))}
                        </Pie>
                        <Pie
                            data={[{ name: "Totalt antall", value: usikkerhet.totaltAntall }]}
                            cx={"50%"}
                            cy={"50%"}
                            labelLine={false}
                            label={renderCustomizedLabelInner}
                            outerRadius={30}
                            fill="white"
                            dataKey="value"
                        />

                        <Tooltip content={customTooltip} />
                    </PieChart>
                </ColumnWrapper>
            ))}
        </Container>
    );
};

const Container = styled.div`
    display: flex;
    flex-wrap: wrap;
    flex-direction: row;
    gap: 0.5rem;
`;
const StyledTekst = styled(Tekst)`
    height: 2rem;
    text-align: center;
    display: flex;
    justify-content: center;
    align-content: center;
    margin-top: 0.5rem;
`;

export const ColumnWrapper = styled.div`
    display: flex;
    flex-direction: column;
    max-width: 260px;
`;
