import React from "react";
import { Hendelser, UsikkerhetKategori } from "../forsinkelseSide/useHentForsinkelsesdata";
import styled from "styled-components";
import { Tekst } from "../../components/fellesKomponenter/typografi/Tekst";
import { sumUsikkerhet } from "./utils";
import { PieChartPerKategori } from "./PieChartPerKategori";
import { PieChartLegend } from "./PieChartLegend";

export const PieChartUsikkerhet = ({ hendelser }: { hendelser: Hendelser[] }) => {
    const usikkerhetHendelser = hendelser.map((hendelse) => hendelse.usikkerhetHendelse).flat();
    const aggregertUsikkerhet = sumUsikkerhet(usikkerhetHendelser);

    const kategoriTimer = [
        UsikkerhetKategori.ANTALL_ARBEIDSTIMER,
        UsikkerhetKategori.TRAFIKKREGULERING_INNENFOR_ELLER_UTENFOR_ARBEIDSTID,
    ];

    const kategoriGjennomslipp = [
        UsikkerhetKategori.UTREGNING_REDUSERT_HASTIGHET,
        UsikkerhetKategori.FARTSGRENSE_OPPRETTHOLDES,
        UsikkerhetKategori.UTREGNING_MANUELL_DIRIGERING,
        UsikkerhetKategori.UTREGNING_LYSREGULERING,
        UsikkerhetKategori.LYSREGULERING_DISTANSE_VEGARBEID,
    ];

    const kategoriTrafikkmengde = [UsikkerhetKategori.TRAFIKKMENGDE_ÅDT];

    const usikkerhetTimer = aggregertUsikkerhet.filter((usikkerhet) =>
        kategoriTimer.includes(usikkerhet.usikkerhetKategori),
    );
    const usikkerhetTrafikkmengde = aggregertUsikkerhet.filter((usikkerhet) =>
        kategoriTrafikkmengde.includes(usikkerhet.usikkerhetKategori),
    );

    const usikkerhetGjennomslipp = aggregertUsikkerhet.filter((usikkerhet) =>
        kategoriGjennomslipp.includes(usikkerhet.usikkerhetKategori),
    );

    const usikkerhetStengtOgPåvirket = aggregertUsikkerhet.filter(
        (usikkerhet) =>
            !kategoriTimer.includes(usikkerhet.usikkerhetKategori) &&
            !kategoriGjennomslipp.includes(usikkerhet.usikkerhetKategori) &&
            !kategoriTrafikkmengde.includes(usikkerhet.usikkerhetKategori),
    );

    return (
        <Container>
            <Wrapper>
                <Tekst størrelse={"L"} bold={true}>
                    Arbeidstimer
                </Tekst>
                <PieChartPerKategori aggregertUsikkerhet={usikkerhetTimer} />
                <PieChartLegend />
            </Wrapper>
            <Wrapper>
                <Tekst størrelse={"L"} bold={true}>
                    Trafikkmengde
                </Tekst>
                <PieChartPerKategori aggregertUsikkerhet={usikkerhetTrafikkmengde} />
                <PieChartLegend />
            </Wrapper>
            <Wrapper>
                <Tekst størrelse={"L"} bold={true}>
                    Redusert hastighet og gjennomslipp
                </Tekst>
                <PieChartPerKategori aggregertUsikkerhet={usikkerhetGjennomslipp} />
                <PieChartLegend />
            </Wrapper>
            <Wrapper>
                <Tekst størrelse={"L"} bold={true}>
                    Påvirket kjørefelt og stengt veg
                </Tekst>
                <PieChartPerKategori aggregertUsikkerhet={usikkerhetStengtOgPåvirket} />
                <PieChartLegend />
            </Wrapper>
        </Container>
    );
};

const Container = styled.div`
    display: flex;
    gap: 1rem;
    flex-wrap: nowrap;
    flex-direction: column;
`;

const Wrapper = styled.div`
    display: flex;
    flex-direction: column;
`;
