import {
    ForsinkelsePerDato,
    UsikkerhetAntall,
    UsikkerhetHendelse,
    UsikkerhetKategori,
    UsikkerhetPerKategori,
    UsikkerhetStørrelse,
} from "../forsinkelseSide/useHentForsinkelsesdata";
import dayjs, { Dayjs } from "dayjs";

export const sumForsinkelseITimerPerDato = (
    forsinkelsePerDato: ForsinkelsePerDato[],
): ForsinkelsePerDato[] => {
    const aggregertData = forsinkelsePerDato.reduce(
        (acc, { dato, forsinkelse }) => {
            if (acc[dato]) {
                acc[dato] += forsinkelse;
            } else {
                acc[dato] = forsinkelse;
            }
            return acc;
        },
        {} as { [key: string]: number },
    );

    return sorterOgFormaterForsinkelse(aggregertData, "DD.MM.YYYY");
};

export function hentForsinkelseIÅrPerDato(
    forsinkelseList: ForsinkelsePerDato[],
): ForsinkelsePerDato[] {
    return forsinkelseList.map((forsinkelse) => ({
        ...forsinkelse,
        forsinkelse: Math.round((forsinkelse.forsinkelse / 24 / 365) * 1000000) / 1000000,
    }));
}

export function sumForsinkelseIÅrPerMåned(
    forsinkelseList: ForsinkelsePerDato[],
): ForsinkelsePerDato[] {
    const aggregertPerKalenderMåned = forsinkelseList.reduce(
        (acc, { dato, forsinkelse }) => {
            const måned = dayjs(dato, "DD.MM.YYYY").format("MM.YYYY");
            if (acc[måned]) {
                acc[måned] += forsinkelse;
            } else {
                acc[måned] = forsinkelse;
            }
            return acc;
        },
        {} as { [key: string]: number },
    );
    return sorterOgFormaterForsinkelse(aggregertPerKalenderMåned, "MM.YYYY");
}

function sorterOgFormaterForsinkelse(
    datoObjekt: { [dato: string]: number },
    format: string,
): ForsinkelsePerDato[] {
    return Object.entries(datoObjekt)
        .map(([dato, forsinkelse]) => ({
            dato: dayjs(dato, format).format(format),
            forsinkelse: rundTilDesimaler(forsinkelse, 5),
        }))
        .sort((a, b) => dayjs(a.dato, format).diff(dayjs(b.dato, format)));
}

export function hentTicksYaxisForsinkelse(forsinkelseIÅr: number[]): number[] {
    const maxForsinkelse = Math.ceil(Math.max(...forsinkelseIÅr)) + 4;
    const possibleTicksYaxis = lagArrayMedInkrementer(maxForsinkelse, 1);
    return possibleTicksYaxis.filter((tick) => tick <= maxForsinkelse);
}

export const lagArrayMedInkrementer = (lengde: number, inkrement: number, start?: number) => {
    return Array.from({ length: lengde }, (_, i) => (start ?? 0) + i * inkrement);
};

export function rundTilDesimaler(nummer: number, desimaler: number): number {
    return parseFloat(nummer.toFixed(desimaler));
}

export function sumUsikkerhet(hendelser: UsikkerhetHendelse[]): UsikkerhetPerKategori[] {
    const sum = hendelser.reduce(
        (acc, current) => {
            const { usikkerhetKategori, usikkerhet } = current;

            if (!acc[usikkerhetKategori]) {
                acc[usikkerhetKategori] = {
                    ingen: 0,
                    liten: 0,
                    medium: 0,
                    stor: 0,
                };
            }

            switch (usikkerhet) {
                case UsikkerhetStørrelse.INGEN:
                    acc[usikkerhetKategori].ingen++;
                    break;
                case UsikkerhetStørrelse.LITEN:
                    acc[usikkerhetKategori].liten++;
                    break;
                case UsikkerhetStørrelse.MIDDELS:
                    acc[usikkerhetKategori].medium++;
                    break;
                case UsikkerhetStørrelse.STOR:
                    acc[usikkerhetKategori].stor++;
                    break;
                default:
                    console.warn("Unexpected usikkerhet value:", usikkerhet);
            }

            return acc;
        },
        {} as Record<UsikkerhetKategori, UsikkerhetAntall>,
    );

    return Object.keys(sum).map((key) => ({
        usikkerhetKategori: key as UsikkerhetKategori,
        usikkerhetAntall: sum[key as UsikkerhetKategori],
        totaltAntall: sumTotalUsikkerhetAntall(sum[key as UsikkerhetKategori]),
    }));
}

export function sumTotalUsikkerhetAntall(data: UsikkerhetAntall): number {
    return data.ingen + data.liten + data.medium + data.stor;
}
