import React, { useState } from "react";
import { InfoKort } from "./InfoKort";
import { Datofelt } from "../../components/fellesKomponenter/inputfelt/Datofelt";
import { Dayjs } from "dayjs";
import styled from "styled-components";
import { KnappPrimær } from "../../components/fellesKomponenter/knapper/KnappPrimær";

interface BeskrivelseKortProps {
    startDato: Dayjs;
    sluttDato: Dayjs;
    setStartDato: (dato: Dayjs) => void;
    setSluttDato: (dato: Dayjs) => void;
}

export const BeskrivelseKort = ({
    startDato,
    sluttDato,
    setSluttDato,
    setStartDato,
}: BeskrivelseKortProps) => {
    const [lokalStartDato, setLokalStartDato] = useState(startDato);
    const [lokalSluttDato, setLokalSluttDato] = useState(sluttDato);

    const handleSubmit = (e: React.FormEvent<HTMLFormElement>) => {
        e.preventDefault();
        setStartDato(lokalStartDato);
        setSluttDato(lokalSluttDato);
    };

    return (
        <InfoKort>
            <StyledForm onSubmit={handleSubmit}>
                <Datofelt dato={startDato} setDato={setLokalStartDato} tittel={"Fra dato"} />
                <Datofelt dato={sluttDato} setDato={setLokalSluttDato} tittel={"Til dato"} />
                <KnappPrimær type="submit" size="Small">
                    Hent data
                </KnappPrimær>
            </StyledForm>
            <h3>Forsinkelsesutregning</h3>
            <p>
                Forsinkelsesanalysen er et styringsverktøy for produktområdet Fremkommelig Veg.
                Analysen gir innblikk i forsinkelser som følge av planlagt vegarbeid.
            </p>
            <p>
                Forsinkelsesanalysen baserer seg på trafikkmeldinger. For hver trafikkmelding
                beregnes tidsdifferansen mellom å kjøre veistrekket under normale forhold og under
                påvirkning av vegarbeidet. Denne differansen multipliseres med antall kjøretøy som
                passerer i timen for å beregne forsinkelsen. Til slutt tas antall timer hendelsen
                pågår med i beregningen.
            </p>
            <p>
                For hver trafikkmelding hentes trafikkavviklingen knyttet til den aktuelle
                trafikkmeldingen. Eksempler på trafikkavviklinger er &quot;redusert hastighet&quot;,
                &quot;lysregulering&quot; eller &quot;stengt vei&quot;. Forsinkelsen knyttet til
                trafikkavviklingen beregnes av en algoritme som tar hensyn til trafikkavvikling,
                vegtype, tidspunkt og trafikkmengde.
            </p>
            <p>
                Det er usikkerhet knyttet til forsinkelsesberegningene. Dette kan skyldes feil eller
                mangelfull innrapportering av data i trafikkmeldingene. Det er også usikkerhet
                knyttet til algoritmen som beregner forsinkelsen, da det gjøres forenklinger og
                estimater for å raskt få et brukbart tall for forsinkelsen. Det arbeides
                kontinuerlig med å redusere usikkerheten og forbedre kvaliteten i analysene.
            </p>
        </InfoKort>
    );
};

const StyledForm = styled.form`
    display: flex;
    flex-direction: row;
    gap: 1rem;
    flex-wrap: wrap;
    align-items: end;
`;
