"use client";

import ErrorBoundary from "../../components/feil/ErrorBoundary";
import { AuthenticationWrapper } from "../../components/AuthenticationWrapper";
import { AnalyseSideHeader } from "../components/analyseSideHeader";
import styled from "styled-components";
import { ForsinkelseKort } from "./ForsinkelseKort";
import { KostnadKort } from "./KostnadKort";
import { UsikkerhetKort } from "./UsikkerhetKort";
import { BeskrivelseKort } from "./BeskrivelseKort";
import { useHentForsinkelsesdata } from "./useHentForsinkelsesdata";
import dayjs from "dayjs";
import { useState } from "react";
import { TransportKorridorerKort } from "./TransportKorridorerKort";

export const ForsinkelseSide = () => {
    const [fraDato, setFraDato] = useState(dayjs().add(-1, "month"));
    const [tilDato, setTilDato] = useState(dayjs());

    const data = useHentForsinkelsesdata(fraDato, tilDato);

    return (
        <ErrorBoundary info={`side: Analyseportal forsinkelse`}>
            <AuthenticationWrapper>
                <AnalyseSideHeader side={"forsinkelser"} />
                {data?.suksess ? (
                    <>
                        <Sideinnhold>
                            <GridView>
                                <div>
                                    <ForsinkelseKort
                                        timerForsinkelse={data.data.totalForsinkelseTimer}
                                    />
                                    <KostnadKort kostnadKr={data.data.totalKostnadKroner} />
                                    <UsikkerhetKort usikkerhet={data.data.usikkerhet} />
                                </div>
                                <BeskrivelseKort
                                    startDato={fraDato}
                                    sluttDato={tilDato}
                                    setSluttDato={(dato) => setTilDato(dato)}
                                    setStartDato={(dato) => setFraDato(dato)}
                                />
                            </GridView>
                            <TransportKorridorerKort
                                transportkoridorerData={data.data.riksvegruter}
                            />
                        </Sideinnhold>
                    </>
                ) : (
                    <>{data?.feilmelding ? <div>{data.feilmelding}</div> : <div>Laster...</div>}</>
                )}
            </AuthenticationWrapper>
        </ErrorBoundary>
    );
};

const Sideinnhold = styled.main`
    width: fit-content;
    margin: 0 auto;
    max-width: 1100px;
`;

const GridView = styled.div`
    display: grid;
    grid-template-columns: minmax(200px, 550px) minmax(100px, 550px);
`;

export default ForsinkelseSide;
