import { GeoJSON, MapContainer, TileLayer, ZoomControl } from "react-leaflet";
import React, { useEffect, useMemo } from "react";
import styles from "../../kartSide/Kartvisning/Kartvisning.module.css";
import "leaflet/dist/leaflet.css";
import {
    TransportKorridor,
    transportKorridorerDtoTilWktGeometri,
    useHentTransportKorridorerGeometri,
} from "./useHentTransportKorridorerGeometri";
import { crsUtm33N } from "../../kartSide/utils/crs";
import { WktTilGeoJsonFeatureCollection } from "./transportKorridorerKartUtils";
import { Spinner } from "../../components/fellesKomponenter/spinner/Spinner";

interface TransportKorridorerKartProps {
    transportKorridor: TransportKorridor;
}

export const TransportKorridorerKart = ({ transportKorridor }: TransportKorridorerKartProps) => {
    const transportKorridorerGeometri = useHentTransportKorridorerGeometri(transportKorridor);

    return (
        <>
            {!transportKorridorerGeometri ? (
                <Spinner />
            ) : (
                <MapContainer
                    className={styles.kartvisningokt}
                    center={[60.7, 9.5022]}
                    zoom={3}
                    crs={crsUtm33N}
                    scrollWheelZoom={false}
                    attributionControl={false}
                    zoomControl={false}
                >
                    <TileLayer
                        attribution="© NVDB, Geovekst, kommunene og Open Street Map contributors (utenfor Norge)"
                        url="https://services.geodataonline.no/arcgis/rest/services/Trafikkportalen/GeocacheTrafikkJPG/MapServer/tile/{z}/{y}/{x}"
                        subdomains="123456789"
                    />
                    <GeoJSON
                        data={WktTilGeoJsonFeatureCollection(
                            transportKorridorerDtoTilWktGeometri(transportKorridorerGeometri.data),
                        )}
                        style={{ color: "orange" }}
                    />
                    <ZoomControl position="bottomright" />
                </MapContainer>
            )}
        </>
    );
};
