import React, { memo, useState } from "react";
import { InfoKort } from "./InfoKort";
import styled from "styled-components";
import { FokusTall } from "../components/fellesKomponenter/FokusTall";
import { FokusTekst } from "../components/fellesKomponenter/FokusTekst";
import { formaterTall, timerTilDager, timerTilÅr } from "./utils";
import dynamic from "next/dynamic";
import { OsloTrondheim, TransportKorridor } from "./useHentTransportKorridorerGeometri";
import { TransportKorridorerDto } from "./useHentForsinkelsesdata";
import { Spinner } from "../../components/fellesKomponenter/spinner/Spinner";
import { TransportKorridorerTrekkspill } from "../components/fellesKomponenter/TransportKorridorerTrekkspill";

interface TransportKorridorerKortProps {
    transportkoridorerData: TransportKorridorerDto[];
}

export const TransportKorridorerKort = ({
    transportkoridorerData,
}: TransportKorridorerKortProps) => {
    const [erTrekkspillÅpen, setErTrekkspillÅpen] = useState(false);
    const [transportKorridor, setTransportKorridor] = useState(OsloTrondheim);

    const håndterTrekkspillKnappKlikk = (transportKorridor: TransportKorridor) => {
        setErTrekkspillÅpen(false);
        setTransportKorridor(transportKorridor);
    };

    return (
        <InfoKort>
            <FlexView>
                <h2>{transportKorridor.navn}</h2>
                <TransportKorridorerTrekkspill
                    erTrekkspillÅpen={erTrekkspillÅpen}
                    setErTrekkspillÅpen={setErTrekkspillÅpen}
                    håndterTrekkspillKnappKlikk={håndterTrekkspillKnappKlikk}
                />
            </FlexView>
            <GridView>
                <div>
                    <p>
                        <FokusTall>
                            {formaterTall(
                                finnTransportKorridor(transportKorridor.id, transportkoridorerData)
                                    ?.totalForsinkelseTimer ?? 0,
                            )}
                        </FokusTall>{" "}
                        <FokusTekst>timer</FokusTekst>
                    </p>
                    <p>
                        <FokusTall>
                            {formaterTall(
                                timerTilDager(
                                    finnTransportKorridor(
                                        transportKorridor.id,
                                        transportkoridorerData,
                                    )?.totalForsinkelseTimer ?? 0,
                                ),
                            )}
                        </FokusTall>{" "}
                        <FokusTekst>dager</FokusTekst>
                    </p>
                    <p>
                        <FokusTall>
                            {formaterTall(
                                timerTilÅr(
                                    finnTransportKorridor(
                                        transportKorridor.id,
                                        transportkoridorerData,
                                    )?.totalForsinkelseTimer ?? 0,
                                ),
                            )}
                        </FokusTall>{" "}
                        <FokusTekst>år</FokusTekst>
                    </p>
                    <p>
                        <FokusTall>
                            {formaterTall(
                                finnTransportKorridor(transportKorridor.id, transportkoridorerData)
                                    ?.totalKostnadKroner ?? 0,
                            )}
                        </FokusTall>{" "}
                        <FokusTekst>kroner</FokusTekst>
                    </p>
                </div>
                <div>
                    <p>
                        Forsinkelse og kostnad som følge av planlagt vegarbeid på
                        transportkorridoren: &quot;{transportKorridor.navn}&quot; i den valgte
                        tidsperioden.
                    </p>
                    <p>Forsinkelsen er summert for begge kjøreretninger</p>
                </div>
                <TransportkorridorKartvining transportKorridor={transportKorridor} />
            </GridView>
        </InfoKort>
    );
};

const TransportkorridorKartvining = memo(
    ({ transportKorridor }: { transportKorridor: TransportKorridor }) => (
        <DynamicTransportkorridorerKartvisning transportKorridor={transportKorridor} />
    ),
);

TransportkorridorKartvining.displayName = "TransportkorridorKartvining";

const DynamicTransportkorridorerKartvisning = dynamic(
    () => import("./TransportKorridorerKart").then((mod) => mod.TransportKorridorerKart),
    {
        loading: () => <Spinner />,
        ssr: false,
    },
);

const finnTransportKorridor = (
    id: string,
    transportKorridorerDto: TransportKorridorerDto[] | undefined,
): TransportKorridorerDto | undefined =>
    transportKorridorerDto?.find((korridor) => korridor.id === id);

const FlexView = styled.div`
    display: flex;
    justify-content: space-between;
    margin-top: 1rem;
`;

const GridView = styled.div`
    display: grid;
    grid-template-columns: 1fr 1fr 2fr;
    gap: 1rem;
`;
