import React from "react";
import { InfoKort } from "./InfoKort";
import styled from "styled-components";
import { Cell, Pie, PieChart } from "recharts";
import { UsikkerhetAntall } from "./useHentForsinkelsesdata";
import {
    PIECHART_COLORS,
    renderCustomizedLabelDetailedOuter,
    renderCustomizedLabelInner,
    usikkerhetsdataTilStatistikkdata,
} from "../utils/piechartUtils";
import { PieChartLegend } from "../forsinkelseDetaljerSide/PieChartLegend";
import { sumTotalUsikkerhetAntall } from "../forsinkelseDetaljerSide/utils";

interface UsikkerhetKortProps {
    usikkerhet: UsikkerhetAntall;
}

export const UsikkerhetKort = ({ usikkerhet }: UsikkerhetKortProps) => {
    const usikkerhetSatistikk = usikkerhetsdataTilStatistikkdata(usikkerhet);
    const totaltAntall = sumTotalUsikkerhetAntall(usikkerhet);
    return (
        <InfoKort>
            <Container>
                <Wrapper>
                    <h3>Usikkerhet</h3>
                    <p>
                        Det er usikkerhet forbundet med forsinkelsesanalysene. Usikkerheten er delt
                        inn i fire kategorier: ingen, liten, medium og stor. Datakvalitet og
                        utregning er de største usikkerhetsfaktorene.
                    </p>
                </Wrapper>
                <Wrapper>
                    <PieChart width={260} height={200}>
                        <Pie
                            data={usikkerhetSatistikk}
                            cx="50%"
                            cy="50%"
                            labelLine={false}
                            label={renderCustomizedLabelDetailedOuter}
                            outerRadius={60}
                            fill="#8884d8"
                            dataKey="value"
                        >
                            {usikkerhetSatistikk.map((entry, index) => (
                                <Cell
                                    key={`cell-${index}`}
                                    fill={PIECHART_COLORS[index % PIECHART_COLORS.length]}
                                />
                            ))}
                        </Pie>
                        <Pie
                            data={[{ name: "Totalt antall", value: totaltAntall }]}
                            cx={"50%"}
                            cy={"50%"}
                            labelLine={false}
                            label={renderCustomizedLabelInner}
                            outerRadius={30}
                            fill="white"
                            dataKey="value"
                        />
                    </PieChart>
                    <PieChartLegend size={"S"} />
                </Wrapper>
            </Container>
        </InfoKort>
    );
};

const Container = styled.div`
    display: flex;
    gap: 1rem;
    align-items: start;
    flex-wrap: wrap;
    width: 100%;
`;

const Wrapper = styled.div`
    display: flex;
    flex-direction: column;
    width: 230px;
`;
