import { FeatureCollection } from "geojson";
import { GeoJSONGeometry, parse } from "wellknown";
import { Proj4GeoJSONFeature } from "proj4leaflet";

export const WktTilGeoJsonFeatureCollection = (wkt: string[]): FeatureCollection => {
    const flipped = wkt.map(flippLatLngKoordinater);
    const geo = flipped.map(parse);
    const features: Proj4GeoJSONFeature[] = geo.map((g) => ({
        type: "Feature",
        geometry: g as GeoJSONGeometry,
        properties: {},
    }));
    return {
        type: "FeatureCollection",
        features: features,
    };
};

export const flippLatLngKoordinater = (wktString: string) => {
    const koordinatType = wktString.split("(")[0];

    const flipLatLng = (pair: string) => {
        const [lat, lng] = pair.split(" ").map(Number);
        return `${lng} ${lat}`;
    };

    if (koordinatType === "LINESTRING") {
        if (
            !wktString.match(
                /^LINESTRING\(\s*(\d+(\.\d+)?\s+\d+(\.\d+)?\s*(,\s*\d+(\.\d+)?\s+\d+(\.\d+)?\s*)*)\)$/,
            )
        ) {
            console.error("Feil format", wktString);
            return "";
        }
        const koordinaterString = wktString.replace("LINESTRING", "").replace(/[()]/g, "");
        const flippedeKoordinater = koordinaterString.split(" , ").map(flipLatLng);

        return `LINESTRING(${flippedeKoordinater.join(" , ")})`;
    }

    if (koordinatType === "MULTILINESTRING") {
        if (
            !wktString.match(
                /^MULTILINESTRING\(\(\s*(\d+(\.\d+)?\s+\d+(\.\d+)?\s*(,\s*\d+(\.\d+)?\s+\d+(\.\d+)?\s*)*)\s*\)(,\s*\(\s*(\d+(\.\d+)?\s+\d+(\.\d+)?\s*(,\s*\d+(\.\d+)?\s+\d+(\.\d+)?\s*)*)\s*\))*\)$/,
            )
        ) {
            console.error("Feil format", wktString);
            return "";
        }

        const koordinaterString = wktString
            .replace("MULTILINESTRING", "")
            .replace(/\(\(|\)\)/g, "");
        const flippedeLinjer = koordinaterString
            .split("), (")
            .map((linje) => `(${linje.split(" , ").map(flipLatLng).join(" , ")})`);

        return `MULTILINESTRING(${flippedeLinjer.join(" , ")})`;
    }

    console.error("Kunne ikke parse koordinater på format: ", koordinatType);
    return "";
};
