import { ApiRespons, FeilType, fetcher, ikkeRevalidate } from "../../api/api";
import { ANALYSE_API_URL } from "../../utils/baseUrl";
import useSWR from "swr";
import dayjs, { Dayjs } from "dayjs";
import { tilIsoDatoString } from "../../utils/tid";
import { useSetAtom } from "jotai";
import { detaljerteHendelserResponsAtom } from "../api/apiAtoms";
import { useEffect } from "react";

export function useHentForsinkelsesdata(
    fraDato: Dayjs,
    tilDato: Dayjs,
): ApiRespons<ForsinkelseDto> | undefined {
    const setDetaljerteHendelserRespons = useSetAtom(detaljerteHendelserResponsAtom);
    const customFetcher = async (): Promise<ApiRespons<ForsinkelseDto>> => {
        const response = await fetcher<ForsinkelseDto>(
            `${ANALYSE_API_URL}/frontendvisning?fraDato=${tilIsoDatoString(fraDato)}&tilDato=${tilIsoDatoString(tilDato)}`,
            FeilType.KUNNE_IKKE_HENTE_FORSINKELSESDATA,
        );
        return {
            ...response,
            data: transformerApiRespons(response.data),
        };
    };

    const { data, isLoading } = useSWR<ApiRespons<ForsinkelseDto>>(
        `${fraDato}-${tilDato}`,
        customFetcher,
        ikkeRevalidate,
    );

    useEffect(() => {
        if (isLoading) {
            setDetaljerteHendelserRespons(undefined);
            return;
        }
        data && setDetaljerteHendelserRespons(data);
    }, [data, isLoading]);
    return data;
}

function transformerApiRespons(apiResponse: any): ForsinkelseDto {
    return {
        ...apiResponse,
        hendelser: apiResponse.hendelser.map((hendelse: any) => ({
            ...hendelse,
            forsinkelseTotal: {
                ...hendelse.forsinkelseTotal,
                forsinkelsePerDato: Object.entries(
                    hendelse.forsinkelseTotal.forsinkelsePerDato,
                ).map(([dato, forsinkelse]) => ({
                    dato: dayjs(dato, "YYYY-MM-DD").format("DD.MM.YYYY"),
                    forsinkelse: forsinkelse,
                })),
            },
            usikkerhetHendelse: hendelse.usikkerhetHendelse.map((usikkerhet: any) => ({
                usikkerhetKategori:
                    UsikkerhetKategori[usikkerhet.first as keyof typeof UsikkerhetKategori],
                usikkerhet:
                    UsikkerhetStørrelse[usikkerhet.second as keyof typeof UsikkerhetStørrelse],
            })),
        })),
    };
}

export interface ForsinkelseDto {
    fraDato: string;
    tilDato: string;
    totalForsinkelseTimer: number;
    totalKostnadKroner: number;
    riksvegruter: TransportKorridorerDto[];
    usikkerhet: UsikkerhetAntall;
    hendelser: Hendelser[];
}

export interface Hendelser {
    forsinkelseTotal: ForsinkelseTotal;
    usikkerhetHendelse: UsikkerhetHendelse;
    lokasjon: Lokasjon[];
    veger: string[];
}

export interface Lokasjon {
    fylke: string;
    kommuner: string[];
}

export interface ForsinkelseTotal {
    forsinkelsePerBil: number;
    forsinkelsePerTime: number;
    forsinkelsePerDato: ForsinkelsePerDato;
    totalForsinkelse: number;
    kostnad: number;
    kostnadPerDato: KostnadPerDato;
}

export interface ForsinkelsePerDato {
    dato: string;
    forsinkelse: number;
}

export interface KostnadPerDato {
    [dato: string]: number;
}

export interface UsikkerhetHendelse {
    usikkerhetKategori: UsikkerhetKategori;
    usikkerhet: UsikkerhetStørrelse;
}
export enum UsikkerhetStørrelse {
    INGEN = "Ingen",
    LITEN = "Liten",
    MIDDELS = "Medium",
    STOR = "Stor",
}

export interface UsikkerhetPerKategori {
    usikkerhetKategori: UsikkerhetKategori;
    usikkerhetAntall: UsikkerhetAntall;
    totaltAntall: number;
}

export interface UsikkerhetAntall {
    ingen: number;
    liten: number;
    medium: number;
    stor: number;
}
export enum UsikkerhetKategori {
    ANTALL_ARBEIDSTIMER = "Antall arbeidstimer",
    TRAFIKKREGULERING_INNENFOR_ELLER_UTENFOR_ARBEIDSTID = "Trafikkregulering innenfor eller utenfor arbeidstid",
    TRAFIKKMENGDE_ÅDT = "Trafikkmengde ÅDT",
    UTREGNING_REDUSERT_HASTIGHET = "Utregning redusert hastighet",
    FARTSGRENSE_OPPRETTHOLDES = "Fartsgrense opprettholdes",
    LYSREGULERING_DISTANSE_VEGARBEID = "Lysregulering distanse vegarbeid",
    UTREGNING_LYSREGULERING = "Utregning lysregulering",
    UTREGNING_MANUELL_DIRIGERING = "Utregning manuell dirigering",
    UTREGNING_STENGT_VEG = "Utregning stengt veg",
    UTREGNING_STENGT_VEG_KORTE_PERIODER = "Utregning stengt veg korte perioder",
    UTREGNING_ETT_STENGT_KJØREFELT = "Utregning ett stengt kjørefelt",
    UTREGNING_PÅVIRKET_KJØREFELT = "Utregning påvirket kjørefelt",
}

export interface TransportKorridorerDto {
    id: string;
    navn: string;
    totalForsinkelseTimer: number;
    totalKostnadKroner: number;
}
