import { ApiRespons, FeilType, fetcher, ikkeRevalidate } from "../../api/api";
import useSWR from "swr";
import dayjs from "dayjs";

export function useHentTransportKorridorerGeometri(
    transportKorridor: TransportKorridor,
): ApiRespons<TransportKorridorerGeometriDto> | undefined {
    const customFetcher = async (): Promise<ApiRespons<TransportKorridorerGeometriDto>> =>
        await fetcher<TransportKorridorerGeometriDto>(
            `https://nvdbapiles-v3.atlas.vegvesen.no/vegobjekter/704?egenskap=11953=${transportKorridor.id}&inkluder=lokasjon&srid=wgs84`,
            FeilType.KUNNE_IKKE_HENTE_GEOMETRI_FOR_TRANSPORTKORRIDORER,
        );
    const { data } = useSWR<ApiRespons<TransportKorridorerGeometriDto>>(
        dayjs().toString(),
        customFetcher,
        ikkeRevalidate,
    );
    return data;
}

export interface TransportKorridorerGeometriDto {
    objekter: {
        lokasjon: {
            geometri: {
                wkt: string;
            };
        };
    }[];
}

export const transportKorridorerDtoTilWktGeometri = (
    transportKorridorDto: TransportKorridorerGeometriDto,
) => {
    return transportKorridorDto.objekter.map((objekt) => {
        return objekt.lokasjon.geometri.wkt
            .replaceAll(" Z", "")
            .replaceAll("-", "")
            .replaceAll(/\d+(\.\d+)?(?=,)|\d+(\.\d+)?(?=\))/g, "");
    });
};

export interface TransportKorridor {
    navn: string;
    id: string;
}

export const OsloTrondheim: TransportKorridor = {
    navn: "Oslo - Trondheim",
    id: "20296",
};

export const OsloStavanger: TransportKorridor = {
    navn: "Oslo - Stavanger",
    id: "20289",
};

export const OsloBergen: TransportKorridor = {
    navn: "Oslo - Bergen",
    id: "20295",
};

export const transportKorridorer: TransportKorridor[] = [OsloTrondheim, OsloStavanger, OsloBergen];
