import { GeoJSON, MapContainer, TileLayer, ZoomControl } from "react-leaflet";
import styles from "../../kartSide/Kartvisning/Kartvisning.module.css";
import { crsUtm33N } from "../../kartSide/utils/crs";
import React, { useMemo } from "react";
import "leaflet/dist/leaflet.css";
import { RiksvegruterDetaljerDto } from "../api/useHentRiksvegruterDetaljer";
import {
    onEachFeature,
    punktTilLayer,
    riksvegruterDetaljerTilFeature,
} from "./RiksvegruterDetaljerKartUtils";

interface RiksvegruterDetaljerKartProps {
    riksvegruterDetaljer: RiksvegruterDetaljerDto[];
    aktivHendelse: string | undefined;
    hoverHendelse: string | undefined;
}

export const RiksvegruterDetaljerKart = ({
    riksvegruterDetaljer,
    aktivHendelse,
    hoverHendelse,
}: RiksvegruterDetaljerKartProps) => {
    const geoJson = useMemo(() => {
        return riksvegruterDetaljer.map((riksvegrute, index) => (
            <GeoJSON
                key={Math.random()}
                data={riksvegruterDetaljerTilFeature(riksvegrute)}
                onEachFeature={(feature, layer) =>
                    onEachFeature(feature, layer, aktivHendelse, hoverHendelse)
                }
                pointToLayer={punktTilLayer}
            ></GeoJSON>
        ));
    }, [riksvegruterDetaljer, aktivHendelse, hoverHendelse]);

    return (
        <MapContainer
            className={styles.kartvisningokt}
            center={[60.7, 9.5022]}
            zoom={3}
            crs={crsUtm33N}
            scrollWheelZoom={false}
            attributionControl={false}
            zoomControl={false}
        >
            <TileLayer
                attribution="© NVDB, Geovekst, kommunene og Open Street Map contributors (utenfor Norge)"
                url="https://services.geodataonline.no/arcgis/rest/services/Trafikkportalen/GeocacheTrafikkJPG/MapServer/tile/{z}/{y}/{x}"
                subdomains="123456789"
            />
            {geoJson}
            <ZoomControl position="bottomright" />
        </MapContainer>
    );
};
