"use client";

import ErrorBoundary from "../../components/feil/ErrorBoundary";
import { AuthenticationWrapper } from "../../components/AuthenticationWrapper";
import { AnalyseSideHeader } from "../components/analyseSideHeader";
import styled from "styled-components";
import { useHentRiksvegruterDetaljer } from "../api/useHentRiksvegruterDetaljer";
import React, { useEffect, useRef, useState } from "react";
import dayjs from "dayjs";
import dynamic from "next/dynamic";
import { Spinner } from "../../components/fellesKomponenter/spinner/Spinner";
import { RiksevegruterDetaljerTabell } from "./RiksvegruterDetaljerTabell";
import { OsloTrondheim } from "../forsinkelseSide/useHentTransportKorridorerGeometri";
import { RiksvegruterDetaljerParameterVelger } from "./RiksvegruterDetaljerParameterVelger";

export const RiksvegruterDetaljerSide = () => {
    const [fraDato, setFraDato] = useState(dayjs().add(-1, "month"));
    const [tilDato, setTilDato] = useState(dayjs());
    const [aktivHendelse, setAktivHendelse] = useState<string | undefined>(undefined);
    const [hoverHendelse, setHoverHendelse] = useState<string | undefined>(undefined);
    const [transportKorridor, setTransportKorridor] = useState(OsloTrondheim);
    const [isSticky, setIsSticky] = useState(false);
    const componentRef = useRef<HTMLDivElement>(null);

    useEffect(() => {
        const handleScroll = () => {
            if (componentRef.current) {
                const { top } = componentRef.current.getBoundingClientRect();
                const isCurrentlySticky = top <= 0;

                setIsSticky(isCurrentlySticky);
            }
        };

        window.addEventListener("scroll", handleScroll);

        return () => {
            window.removeEventListener("scroll", handleScroll);
        };
    }, []);

    const data = useHentRiksvegruterDetaljer(fraDato, tilDato, transportKorridor);

    return (
        <ErrorBoundary info={`side: Analyseportal riksveiruter`}>
            <AuthenticationWrapper>
                <AnalyseSideHeader side={"forsinkelser"} />
                {data?.suksess ? (
                    <>
                        <Sideinnhold>
                            <RiksvegruterDetaljerParameterVelger
                                fraDato={fraDato}
                                setFraDato={setFraDato}
                                tilDato={tilDato}
                                setTilDato={setTilDato}
                                setTransportKorridor={setTransportKorridor}
                            />
                            <KartvisningContainer ref={componentRef}>
                                <StyledKartvisningWrapper isSticky={isSticky}>
                                    <DynamicRiksvegruterDetaljertKartvisning
                                        riksvegruterDetaljer={data.data}
                                        aktivHendelse={aktivHendelse}
                                        hoverHendelse={hoverHendelse}
                                    />
                                </StyledKartvisningWrapper>
                            </KartvisningContainer>
                            <RiksevegruterDetaljerTabell
                                riksvegruterDetaljer={data.data}
                                fraDato={fraDato}
                                tilDato={tilDato}
                                aktivHendelse={aktivHendelse}
                                setAktivHendelse={setAktivHendelse}
                                setHoverHendelse={setHoverHendelse}
                            />
                        </Sideinnhold>
                    </>
                ) : (
                    <>{data?.feilmelding ? <div>{data.feilmelding}</div> : <div>Laster...</div>}</>
                )}
            </AuthenticationWrapper>
        </ErrorBoundary>
    );
};

const Sideinnhold = styled.main`
    width: 100%;
    margin: 0 auto;
    max-width: 1100px;
`;

const StyledKartvisningWrapper = styled.div<{ isSticky: boolean }>`
    position: ${(props) => (props.isSticky ? "fixed" : "relative")};
    top: ${(props) => (props.isSticky ? "0" : "auto")};
    width: inherit;
    height: inherit;
    max-width: 1100px;
`;

const KartvisningContainer = styled.div`
    width: 100%;
    height: 400px;
    left: 0;
    transition: top 0.3s ease;
    z-index: 1000;
`;

export default RiksvegruterDetaljerSide;

const DynamicRiksvegruterDetaljertKartvisning = dynamic(
    () => import("./RiksvegruterDetaljerKart").then((mod) => mod.RiksvegruterDetaljerKart),
    {
        loading: () => <Spinner />,
        ssr: false,
    },
);
