import { tilNorskTimestamp } from "../../utils/tid";
import styled from "styled-components";
import { RiksvegruterDetaljerDto } from "../api/useHentRiksvegruterDetaljer";
import dayjs, { Dayjs } from "dayjs";
import { formaterTall } from "../forsinkelseSide/utils";
import {
    finnForsinkelseITidsperiode,
    finnKostnadITidsperiode,
} from "./RiksvegruterDetaljerTabellUtils";

interface RiksvegruterDetaljerTabellProps {
    riksvegruterDetaljer: RiksvegruterDetaljerDto[];
    fraDato: Dayjs;
    tilDato: Dayjs;
    aktivHendelse: string | undefined;
    setAktivHendelse: (hendelse: string) => void;
    setHoverHendelse: (hendelse: string) => void;
}

export const RiksevegruterDetaljerTabell = ({
    riksvegruterDetaljer,
    fraDato,
    tilDato,
    aktivHendelse,
    setAktivHendelse,
    setHoverHendelse,
}: RiksvegruterDetaljerTabellProps) => {
    return (
        <>
            <StyledTable>
                <thead>
                    <StyledTableRow>
                        <StyledTh>Start tidspunkt</StyledTh>
                        <StyledTh>Slutt tidspunkt</StyledTh>
                        <StyledTh>Beskrivelse</StyledTh>
                        <StyledTh>Total timer arbeid</StyledTh>
                        <StyledTh>Total forsinkelse timer</StyledTh>
                        <StyledTh>Forsinkelse i tidsperiode timer</StyledTh>
                        <StyledTh>Total kostnad kroner</StyledTh>
                        <StyledTh>Kostnad i tidsperiode kroner</StyledTh>
                    </StyledTableRow>
                </thead>
                <tbody>
                    {riksvegruterDetaljer.map((riksvegruterDetalje, index) => (
                        <StyledTableRowHover
                            key={index}
                            onClick={() => setAktivHendelse(riksvegruterDetalje.id)}
                            onMouseOver={() => setHoverHendelse(riksvegruterDetalje.id)}
                            valgt={riksvegruterDetalje.id === aktivHendelse}
                        >
                            <StyledTd>
                                {tilNorskTimestamp(dayjs(riksvegruterDetalje.startDato))}
                            </StyledTd>
                            <StyledTd>
                                {tilNorskTimestamp(dayjs(riksvegruterDetalje.sluttDato))}
                            </StyledTd>
                            <StyledTd>{riksvegruterDetalje.beskrivelse}</StyledTd>
                            <StyledTd>
                                {formaterTall(Math.ceil(riksvegruterDetalje.timerArbeid))} timer
                            </StyledTd>
                            <StyledTd>
                                {formaterTall(Math.ceil(riksvegruterDetalje.totalForsinkelseTimer))}{" "}
                                timer
                            </StyledTd>
                            <StyledTd>
                                {formaterTall(
                                    Math.ceil(
                                        finnForsinkelseITidsperiode(
                                            riksvegruterDetalje,
                                            fraDato,
                                            tilDato,
                                        ),
                                    ),
                                )}{" "}
                                timer
                            </StyledTd>
                            <StyledTd>
                                {formaterTall(riksvegruterDetalje.totalKostnadKroner)} kroner
                            </StyledTd>
                            <StyledTd>
                                {" "}
                                {formaterTall(
                                    Math.ceil(
                                        finnKostnadITidsperiode(
                                            riksvegruterDetalje,
                                            fraDato,
                                            tilDato,
                                        ),
                                    ),
                                )}{" "}
                                kroner
                            </StyledTd>
                        </StyledTableRowHover>
                    ))}
                </tbody>
            </StyledTable>
        </>
    );
};
export const StyledTableRow = styled.tr`
    background-color: #ffffff;
`;

interface StyledTableRowHoverProps {
    valgt: boolean;
}

export const StyledTableRowHover = styled.tr<StyledTableRowHoverProps>`
    background-color: ${(props) => (props.valgt ? "#ddd" : "#fff")};
    &:hover {
        background-color: #ddd;
        cursor: pointer;
    }
`;

export const StyledTd = styled.td`
    padding: 8px;
    border: 1px solid #ddd;
    text-align: left;
    font-size: 14px;
`;

export const StyledTh = styled.th`
    padding: 8px;
    border: 1px solid #ddd;
    border-bottom: 2px solid var(--orange);
    text-align: left;
    font-size: 14px;
`;

export const StyledTable = styled.table`
    border-collapse: collapse;
    width: 100%;
    margin-top: 10px;
    table-layout: auto;
`;
